import 'dart:convert';
import 'dart:io';

import 'package:flutter/foundation.dart';

Map<String, dynamic> urlOrPathOrBase64(String input) {
  final result = <String, dynamic>{
    'isNormalUrl': false,
    'isFilePath': false,
    'isBase64String': false,
  };

  // Check if the input is a normal URL
  if (input.startsWith('http://') || input.startsWith('https://')) {
    result['isNormalUrl'] = true;
  }

  // Check if the input is a local file path on iOS or Android
  if (!kIsWeb) {
    if (Platform.isIOS || Platform.isAndroid) {
      const iosPathPrefix = '/Users/';
      const androidPathPrefix = '/data/';
      if (input.startsWith(iosPathPrefix) ||
          input.startsWith(androidPathPrefix)) {
        result['isFilePath'] = true;
      }
    }
  }

  // Check if the input is a Base64 string
  try {
    final decodedBytes = base64.decode(input);
    if (decodedBytes.isNotEmpty) {
      result['isBase64String'] = true;
    }
  } catch (_) {}

  return result;
}

bool isBase64(String input) {
  input = cleanBase64(input);
  bool isBase64 = !input.contains(' ') &&
      !input.contains('.') &&
      ((input.length % 4 == 0) &&
          base64.decode(input).isNotEmpty &&
          RegExp(r'^([A-Za-z0-9+/])*([A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$')
              .hasMatch(input));

  return isBase64;
}

String cleanBase64(String base64String) {
  List<String> parts = base64String.split("base64,");
  if (parts.length > 1) {
    return parts[1];
  } else {
    // If the string doesn't contain "base64,", return the original string
    return base64String;
  }
}

double adjustMinHeight(double? minHeight) {
  return (minHeight != null && minHeight > 400) ? 350 : (minHeight ?? 150);
}

double adjustMaxHeight(double? maxHeight) {
  return (maxHeight != null && maxHeight > 400) ? 350 : (maxHeight ?? 350);
}

double adjustMinWidth(double? minWidth) {
  return (minWidth != null && minWidth > 400) ? 350 : (minWidth ?? 150);
}

double adjustMaxWidth(double? maxWidth) {
  return (maxWidth != null && maxWidth > 400) ? 350 : (maxWidth ?? 350);
}
