import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_cache_manager/flutter_cache_manager.dart';

class AudioPlaceHolder extends StatelessWidget {
  const AudioPlaceHolder({Key? key, required this.error}) : super(key: key);
  final bool error;

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        // Play button with white background and circular border
        Container(
          width: 48,
          height: 48,
          decoration: const BoxDecoration(
            color: Colors.white,
            shape: BoxShape.circle,
          ),
          child: Center(
            child: error
                ? const Icon(
                    Icons.error,
                    color: Colors.red,
                  )
                : const SizedBox(
                    width: 24,
                    height: 24,
                    child: CircularProgressIndicator(
                      strokeWidth: 1,
                      color: Color(0xFF2BCA72),
                    ),
                  ),
          ),
        ),

        const SizedBox(width: 8),
        // Image placeholder
        //while Audio is still cashing
        //https://github.com/vengamo/vengamo-chat-ui/assets/133201077/55bfb7e4-6cf4-4473-bd51-5d557d3f62a2
        CachedNetworkImage(
          height: 30,
          imageUrl:
              'https://github.com/vengamo/vengamo-chat-ui/assets/133201077/55bfb7e4-6cf4-4473-bd51-5d557d3f62a2',
          cacheManager: DefaultCacheManager(),
          placeholder: (context, url) => const Center(
            child: SizedBox(
              height: 10,
              width: 10,
              child: CircularProgressIndicator(
                strokeWidth: 1,
                color: Colors.white,
              ),
            ),
          ),
          errorWidget: (context, url, error) => const Icon(Icons.error),
        )
      ],
    );
  }
}
