import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class ImageWithLoadingIndicator extends StatelessWidget {
  final String imagePath;
  const ImageWithLoadingIndicator(
      {super.key,
      required this.imagePath,
      this.imageStyles,
      required this.constraints});
  // styles that will be applies on Image.
  final BoxConstraints? imageStyles;
  final BoxConstraints constraints;

  @override
  Widget build(BuildContext context) {
    if (kIsWeb) {
      // Your web-specific code here
      return const Placeholder();
    } else {
      final platformImagePath = Platform.isIOS
          ? imagePath // Use the iOS file path
          : imagePath.replaceAll(
              'file://', ''); // Remove 'file://' prefix for Android
      return Stack(
        alignment: Alignment.center,
        children: [
          ClipRRect(
            borderRadius: BorderRadius.circular(9),
            child: Container(
              constraints: BoxConstraints(
                maxWidth: constraints.maxWidth * 0.8,
                maxHeight: 330,
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(9),
                image: DecorationImage(
                  image: FileImage(File(platformImagePath)),
                  fit: BoxFit.cover,
                  colorFilter: const ColorFilter.mode(
                    Colors.black26,
                    BlendMode.colorBurn,
                  ),
                ),
              ),
            ),
          ),
          const Center(
            child: CircularProgressIndicator(
              color: Colors.white,
              strokeWidth: 1.0,
            ),
          ),
        ],
      );
    }
  }
}
