import 'package:flutter/material.dart';
import '../seen_status.dart';

class TextWidget extends StatelessWidget {
  const TextWidget(
      {super.key,
      required this.isMe,
      required this.message,
      required this.ack,
      required this.time,
      required this.timeLabelColor,
      required this.textStyle,
      required this.messageReply,
      this.messageReplyBgColor,
      this.messageReplyBorderColor});
  final bool isMe;
  final Widget message;
  final Widget ack;
  final String time;
  final Color timeLabelColor;
  final TextStyle? textStyle;

  /// the background color applied to the message reply
  final Color? messageReplyBgColor;

  /// the Border color applied to the message reply
  final Color? messageReplyBorderColor;

  /// message Reply
  final Widget? messageReply;

  @override
  Widget build(BuildContext context) {
    return Padding(
        key: key,
        padding: EdgeInsets.symmetric(
            horizontal: messageReply != null ? 10 : 15, vertical: 2),
        child: Wrap(
          crossAxisAlignment: WrapCrossAlignment.end,
          runAlignment: WrapAlignment.end,
          alignment: WrapAlignment.end,
          spacing: 18,
          children: [
            Padding(
                padding: const EdgeInsets.only(
                    top: 5.0, bottom: 6.0, left: 1, right: 1),
                child: messageReply != null
                    ? Column(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          if (messageReply != null)
                            Stack(
                              children: [
                                Container(
                                  width: double.infinity,
                                  decoration: BoxDecoration(
                                      color: messageReplyBgColor ??
                                          (isMe
                                              ? const Color(0xFFB3D19D)
                                                  .withOpacity(0.5)
                                              : Colors.grey[300])),
                                  child: Padding(
                                    padding: const EdgeInsets.all(8),
                                    child: message,
                                  ),
                                ),
                                Positioned(
                                  top: 0,
                                  bottom: 0,
                                  left:
                                      -1.5, // Adjust the value as needed for your design // Adjust the value as needed for your design
                                  child: Container(
                                    decoration: BoxDecoration(
                                      color: messageReplyBorderColor ??
                                          (isMe
                                              ? const Color(0xFF2BCA72)
                                              : Colors.grey),
                                      borderRadius: const BorderRadius.only(
                                        topLeft: Radius.circular(25),
                                        bottomLeft: Radius.circular(25),
                                      ),
                                    ),

                                    width: 5, // Border width// Border color
                                  ),
                                ),
                              ],
                            ),
                          messageReply ?? Container()
                        ],
                      )
                    : message),
            Padding(
              padding: const EdgeInsets.only(bottom: 0.0),
              child: SeenStatus(
                  isMe: isMe,
                  time: time,
                  dateTextColor: timeLabelColor,
                  messageAck: ack),
            ),
          ],
        ));
  }
}
