import 'package:flutter/material.dart';
import 'package:vengamo_chat_ui/components/text_widget.dart';
import '../BubbleDesign/whatsapp_arrow.dart';
import '../dismissable_bubble.dart';
import 'audio_widget.dart';
import 'image_widget.dart';

class ChatBubbleWithoutAvatar extends StatelessWidget {
  const ChatBubbleWithoutAvatar(
      {super.key,
      required this.isMe,
      required this.message,
      required this.constraints,
      required this.senderBgColor,
      required this.receiverBgColor,
      required this.isNextMessageFromSameSender,
      required this.pointer,
      required this.ack,
      required this.time,
      required this.timeLabelColor,
      required this.imgUrl,
      required this.caption,
      required this.showLoadingOverlay,
      required this.percentage,
      required this.onImageTap,
      this.isAudio,
      this.audioSource,
      this.isLoading,
      this.textStyle,
      this.onSwipe,
      this.onLongPress,
      this.imageStyles,
      required this.messageReply,
      required this.messageReplyBgColor,
      required this.messageReplyBorderColor,
      this.onPress});

  final bool isMe;
  final Widget message;

  /// message Reply
  final Widget? messageReply;

  final BoxConstraints constraints;
  final Color senderBgColor;
  final Color receiverBgColor;

  /// the background color applied to the message reply
  final Color? messageReplyBgColor;

  /// the Border color applied to the message reply
  final Color? messageReplyBorderColor;

  final bool isNextMessageFromSameSender;
  final bool pointer;
  final Widget ack;
  final String time;
  final Color timeLabelColor;

  /// Represents the URL of an image.
  final String imgUrl;

  /// Represents the caption or textual description associated with an image.
  final Widget? caption;

  /// Add this boolean variable to control the visibility of the loading overlay
  final bool showLoadingOverlay;

  /// The `percentage` represents the progress of the image upload or download operation.
  /// It indicates the completion percentage of the image transfer process,
  /// providing feedback to the user about the progress of the operation.
  /// The value of `percentage` ranges from 0.0 to 1.0, where 0.0 represents no progress,
  /// and 1.0 represents the completion of the operation.
  final double percentage;

  //call back function that will be fired on tap.
  final VoidCallback onImageTap;

  ///call back function that will be fired on Press.
  final VoidCallback? onPress;

  ///Boolean for audio message
  final bool? isAudio;

  ///Audio source
  ///in this Version we're supporting only remote files, local files in coming version
  final String? audioSource;

  ///This can be very useful when uploading audio to the server and is not yet done uploading
  final bool? isLoading;

  /// style that will be applied on text;
  final TextStyle? textStyle;

  ///call back function that will be fired when the user swipe;
  final DismissDirectionCallback? onSwipe;

  ///call back function when the message is long pressed
  final GestureLongPressCallback? onLongPress;

  /// styles that will be applies on Image.
  final BoxConstraints? imageStyles;

  String extractData(Widget message, String imageUrl) {
    if (imageUrl.isEmpty || isAudio == true) {
      return 'text';
    } else {
      return 'image';
    }
  }

  @override
  Widget build(BuildContext context) {
    /// final size = MediaQuery.of(context).size;
    return GestureDetector(
      onTap: onPress,
      onLongPress: onLongPress,
      child: DismssibleBubble(
        onSwipe: onSwipe,
        isMe: isMe,
        child: Wrap(
          children: [
            Stack(
              children: [
                Align(
                  alignment:
                      isMe ? Alignment.bottomRight : Alignment.bottomLeft,
                  child: Stack(clipBehavior: Clip.none, children: [
                    Column(
                      children: [
                        extractData(message, imgUrl) == "image"
                            ? Container(
                                constraints: BoxConstraints(
                                  maxWidth: constraints.maxWidth * 0.8,
                                ),
                                margin: EdgeInsets.only(
                                  top: isNextMessageFromSameSender ? 2 : 10,
                                  bottom: 1,
                                ),
                                child: ImageWidget(
                                    messageReply: messageReply,
                                    messageReplyBgColor: messageReplyBgColor,
                                    messageReplyBorderColor:
                                        messageReplyBorderColor,
                                    textStyle: textStyle,
                                    onTap: onImageTap,
                                    imgUrl: imgUrl,
                                    caption: caption,
                                    constraints: constraints,
                                    color:
                                        isMe ? senderBgColor : receiverBgColor,
                                    isMe: isMe,
                                    message: message,
                                    ack: ack,
                                    time: time,
                                    timeLabelColor: timeLabelColor,
                                    showLoadingOverlay: showLoadingOverlay,
                                    percentage: percentage,
                                    imageStyles: imageStyles),
                              )
                            : Container(
                                constraints: BoxConstraints(
                                  maxWidth: constraints.maxWidth * 0.8,
                                ),
                                margin: EdgeInsets.only(
                                  top: isNextMessageFromSameSender ? 2 : 10,
                                  bottom: 1,
                                ),
                                decoration: BoxDecoration(
                                  color: isMe ? senderBgColor : receiverBgColor,
                                  borderRadius: BorderRadius.only(
                                    topLeft: const Radius.circular(9),
                                    topRight: const Radius.circular(9),
                                    bottomLeft: isMe
                                        ? const Radius.circular(9)
                                        : const Radius.circular(9),
                                    bottomRight: const Radius.circular(9),
                                  ),
                                  boxShadow: [
                                    BoxShadow(
                                      color: Colors.black.withOpacity(0.13),
                                      blurRadius: 1,
                                      offset: const Offset(0, 1),
                                    ),
                                  ],
                                ),
                                child: isAudio!
                                    ? AudioWidget(
                                        messageReply: messageReply,
                                        messageReplyBgColor:
                                            messageReplyBgColor,
                                        messageReplyBorderColor:
                                            messageReplyBorderColor,
                                        isMe: isMe,
                                        audioSource: audioSource!,
                                        ack: ack,
                                        senderBgColor: senderBgColor,
                                        receiverBgColor: receiverBgColor,
                                        time: time,
                                        timeLabelColor: timeLabelColor,
                                        isLoading: isLoading!)
                                    : TextWidget(
                                        messageReply: messageReply,
                                        textStyle: textStyle,
                                        isMe: isMe,
                                        message: message,
                                        ack: ack,
                                        time: time,
                                        timeLabelColor: timeLabelColor,
                                        messageReplyBgColor:
                                            messageReplyBgColor,
                                        messageReplyBorderColor:
                                            messageReplyBorderColor),
                              ),
                      ],
                    ),
                    if (isMe && !isNextMessageFromSameSender && pointer && extractData(message, imgUrl) != "image")
                      Positioned(
                        right: -8,
                        top: 19,
                        child: CustomPaint(
                          painter: WhatsAppTrianglePainter(
                              isLeft: false,
                              bg: isMe ? senderBgColor : receiverBgColor),
                          size: const Size(12, 12),
                        ),
                      ),
                    if (!isMe && !isNextMessageFromSameSender && pointer && extractData(message, imgUrl) != "image")
                      Positioned(
                        left: -8,
                        top: 19,
                        child: CustomPaint(
                          painter: WhatsAppTrianglePainter(
                              isLeft: true,
                              bg: isMe ? senderBgColor : receiverBgColor),
                          size: const Size(12, 12),
                        ),
                      ),
                  ]),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
